@@ -84,8 +84,9 @@ def files_touched(git_range):
         if SHA1_REGEX.match(line):
             commit = line
         elif line.strip():
-            filename = line.split('\t')[-1]
-            state = line[37]
+            split_line = line.split('\t')
+            filename = split_line[-1]
+            state = split_line[0].split(' ')[-1][0]
             commits[commit].append(GitFile(filename, state))
     return commits
 
@@ -188,10 +189,10 @@ def valid_range(git_range):
     return len(lines) > 0
 
 
-def convert_since(since, path=None):
+def convert_since(since, branch=None):
     cmd = 'git', 'log', '--pretty=%H', "--since=%s" % since
-    if path:
-        cmd = cmd + (path,)
+    if branch:
+        cmd = cmd + (branch,)
     data = run_command(*cmd)
     lines = data.splitlines()
     if len(lines) == 0:
